@@ -4,6 +4,7 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
+#include <skalibs/types.h>
 #include <skalibs/sgetopt.h>
 #include <skalibs/strerr.h>
 #include <skalibs/stralloc.h>
@@ -21,9 +22,10 @@ int main (int argc, char const **argv, char const *const *envp)
   subgetopt localopt = SUBGETOPT_ZERO ;
   int argc1, fdwstat ;
   stralloc value = STRALLOC_ZERO ;
-  char const *var ;
-  char const *val ;
-  int insist = 2, chomp = 1, doimport = 0 ;
+  char val1[UINT_FMT] ;
+  char const *var[2] = { [1] = "?" } ;
+  char const *val[2] = { [1] = val1 } ;
+  int insist = 2, chomp = 1, doimport = 0, allgood = 0 ;
   char const *def = 0 ;
   PROG = "backtick" ;
   for (;;)
@@ -47,7 +49,7 @@ int main (int argc, char const **argv, char const *const *envp)
 
   if (argc < 2) dieusage() ;
   if (!argv[0][0] || strchr(argv[0], '=')) strerr_dief1x(100, "invalid variable name") ;
-  argc-- ; var = *argv++ ;
+  argc-- ; var[0] = *argv++ ;
   argc1 = el_semicolon(argv) ;
   if (!argc1) strerr_dief1x(100, "empty block") ;
   if (argc1 >= argc) strerr_dief1x(100, "unterminated block") ;
@@ -62,12 +64,12 @@ int main (int argc, char const **argv, char const *const *envp)
     if (wait_pid(pid, &fdwstat) < 0) strerr_diefu1sys(111, "wait_pid") ;
   }
 
-  val = value.s ;
+  val[0] = value.s ;
   if (wait_status(fdwstat))
   {
     if (insist >= 2)
       strerr_dief1x(wait_estatus(fdwstat), WIFSIGNALED(fdwstat) ? "child process crashed" : "child process exited non-zero") ;
-    else if (insist) val = def ;
+    else if (insist) val[0] = def ;
   }
   else if (strlen(value.s) < value.len - 1)
   {
@@ -75,13 +77,14 @@ int main (int argc, char const **argv, char const *const *envp)
       strerr_dief1x(124, "child process output contained a null character") ;
     else if (insist)
     {
-      val = def ;
+      val[0] = def ;
       strerr_warnw1x("child process output contained a null character") ;
     }
     else value.len = strlen(value.s) + 1 ;
   }
-  else insist = 0 ;
-  if (!insist && chomp && (value.s[value.len - 2] == '\n'))
+  else allgood = 1 ;
+  if ((!insist || allgood) && chomp && (value.s[value.len - 2] == '\n'))
     value.s[--value.len - 1] = 0 ;
-  el_modif_and_exec(argv + argc1 + 1, var, val, doimport) ;
+  val1[uint_fmt(val1, wait_status(fdwstat))] = 0 ; 
+  el_modifs_and_exec(argv + argc1 + 1, var, val, insist < 2 ? 2 : 1, doimport) ;
 }
